import React from 'react';
import { Link } from 'react-router-dom';
import { ArrowRight, Bot, MessageSquare, Mail, Phone, Globe, Calendar, Star, CheckCircle2, BrainCircuit } from 'lucide-react';

const Hero = () => {
  return (
    <section id="hero" className="relative min-h-[90vh] flex items-center pt-20 sm:pt-24">
      {/* Enhanced gradient background */}
      <div className="absolute inset-0">
        <div className="absolute inset-0 bg-gradient-to-b from-white via-white to-transparent" />
        {/* Background effects - hidden on mobile */}
        <div className="hidden lg:block">
          {/* Top right glow */}
          <div className="absolute inset-0 bg-[radial-gradient(ellipse_at_top_right,_rgba(14,_165,_233,_0.15)_0%,_transparent_60%)]" />
          {/* Bottom left glow that extends into Why Choose Us */}
          <div className="absolute bottom-0 left-0 w-full h-[800px] bg-[radial-gradient(ellipse_at_center,_rgba(14,_165,_233,_0.15)_0%,_transparent_70%)]" />
          {/* Smooth transition gradient */}
          <div className="absolute bottom-0 left-0 right-0 h-[300px] bg-gradient-to-b from-transparent via-primary-50/20 to-primary-50/30" />
        </div>
      </div>

      <div className="relative w-full max-w-7xl mx-auto px-4 sm:px-6 py-12 sm:py-24">
        <div className="grid lg:grid-cols-2 gap-12 lg:gap-20 items-center">
          <div className="max-w-2xl">
            <h1 className="text-3xl sm:text-4xl lg:text-5xl font-bold tracking-tight leading-[1.15]" aria-label="24/7 AI-Powered Customer Communication">
              <span className="text-secondary-900">Automated Business Solution for</span>
              <span className="block mt-4 bg-gradient-to-r from-primary-600 via-primary-500 to-primary-600 bg-clip-text text-transparent">
                24/7 Customer Communication
              </span>
            </h1>

            <p className="mt-6 sm:mt-8 text-lg sm:text-xl text-secondary-600 leading-relaxed" aria-label="AI-powered customer communication across all channels">
              Sales Assist AI revolutionizes customer communication across every channel from phone and email to WhatsApp, social media, live chat, and more. Acting as an extension of your best employee, it delivers unparalleled omnichannel service around the clock ensuring you never miss an opportunity to connect, engage, and convert.
            </p>

            <div className="mt-8 sm:mt-10 flex flex-col sm:flex-row items-stretch sm:items-center gap-4 sm:gap-6 lg:flex">
              <Link 
                to="/book-demo" 
                className="btn-primary group flex-1 sm:flex-none relative z-10"
              >
                Book Your Demo
                <ArrowRight className="ml-2 w-5 h-5 group-hover:translate-x-0.5 transition-transform" />
              </Link>
              <Link 
                to="/demo" 
                className="btn-secondary group flex-1 sm:flex-none relative z-10"
              >
                Explore Online Demos
                <ArrowRight className="ml-2 w-5 h-5 group-hover:translate-x-0.5 transition-transform" />
              </Link>
            </div>
          </div>

          <div className="hidden lg:block lg:ml-auto w-full max-w-full">
            <div className="relative">
              {/* AI Processing Flow */}
              <div className="relative h-[500px] overflow-hidden">
                {/* Central AI Brain */}
                <div className="absolute left-1/2 top-1/2 -translate-x-1/2 -translate-y-1/2 z-20 transition-all">
                  <div className="relative">
                    <div className="absolute inset-0 bg-gradient-to-br from-primary-500/30 to-primary-600/30 rounded-full blur-2xl animate-[pulse_3s_ease-in-out_infinite]" />
                    <div className="relative w-32 h-32 rounded-full bg-gradient-to-br from-primary-500 to-primary-600 flex items-center justify-center [animation:robotFlash_2s_ease-in-out_infinite]">
                      <Bot className="w-16 h-16 text-white" />
                    </div>
                    {/* Pulsing rings */}
                    <div className="absolute inset-0 rounded-full border-2 border-primary-500/30 animate-[ping_6s_cubic-bezier(0,0,0.2,1)_infinite]" />
                    <div className="absolute inset-0 rounded-full border-2 border-primary-500/20 animate-[ping_6s_cubic-bezier(0,0,0.2,1)_infinite_2s]" />
                  </div>
                </div>

                {/* Input Flow - Left Side */}
                <div className="absolute left-0 top-0 bottom-0 w-1/3 flex flex-col justify-center gap-4">
                  {/* Animated leads flowing in */}
                  <div className="space-y-3 relative z-10">
                    <div className="absolute left-full top-1/2 -translate-y-1/2 w-[200px] h-[2px]">
                      <div className="absolute inset-0 bg-gradient-to-r from-primary-200/80 via-primary-200/30 to-transparent blur-[1px]" />
                      <div className="absolute inset-0 bg-gradient-to-r from-primary-200/50 via-primary-200/20 to-transparent" />
                    </div>
                    {[
                      { label: 'Email Lead', icon: Mail },
                      { label: 'Phone Inquiry', icon: Phone },
                      { label: 'Chat Message', icon: MessageSquare },
                      { label: 'Social Lead', icon: Globe }
                    ].map((item, index) => (
                      <div 
                        key={index}
                        className="opacity-0 animate-[slideInToCenter_8s_ease-in-out_infinite]"
                        style={{ animationDelay: `${index * 2}s` }}
                      >
                        <div className="flex items-center gap-2 bg-white/90 backdrop-blur-sm rounded-xl p-3 border border-primary-100/50 shadow-sm transition-all">
                          <div className="w-8 h-8 rounded-lg bg-primary-50 flex items-center justify-center">
                            {React.createElement(item.icon, { className: "w-4 h-4 text-primary-600" })}
                          </div>
                          <span className="text-sm text-secondary-600">{item.label}</span>
                        </div>
                      </div>
                    ))}
                  </div>
                </div>
                {/* Output Flow - Right Side */}
                <div className="absolute right-0 top-0 bottom-0 w-1/3 flex flex-col justify-center gap-4">
                  {/* Animated successful outcomes */}
                  <div className="relative z-10">
                    <div className="absolute right-full top-1/2 -translate-y-1/2 w-[200px] h-[2px]">
                      <div className="absolute inset-0 bg-gradient-to-r from-transparent via-green-200/30 to-green-200/80 blur-[1px]" />
                      <div className="absolute inset-0 bg-gradient-to-r from-transparent via-green-200/20 to-green-200/50" />
                    </div>
                    {[
                      { label: 'Email Responded', icon: Mail },
                      { label: 'Follow-up Sent', icon: MessageSquare },
                      { label: 'Call Answered', icon: Phone },
                      { label: 'Meeting Booked', icon: Calendar },
                      { label: 'Lead Qualified', icon: CheckCircle2 },
                      { label: 'Review Requested', icon: Star }
                    ].map((item, index) => (
                      <div 
                        key={index}
                        className="absolute top-1/2 -translate-y-1/2 opacity-0 animate-[slideOutFromCenter_12s_ease-in-out_infinite]"
                        style={{ animationDelay: `${index * 10}s` }}
                      >
                        <div className="flex items-center gap-2 bg-green-50/90 backdrop-blur-sm rounded-xl p-3 border border-green-100 shadow-sm transition-all">
                          <div className="w-8 h-8 rounded-lg bg-green-100 flex items-center justify-center">
                            {React.createElement(item.icon, { className: "w-4 h-4 text-green-600" })}
                          </div>
                          <span className="text-sm text-green-700">{item.label}</span>
                        </div>
                      </div>
                    ))}
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
        
      </div>
      <style>
      {`
        @keyframes slideInToCenter {
          0% { transform: translateX(0); opacity: 0; filter: blur(4px); }
          15% { transform: translateX(0); opacity: 0.8; filter: blur(0); }
          25% { transform: translateX(0); opacity: 1; filter: blur(0); }
          50% { transform: translateX(50px); opacity: 1; filter: blur(0); }
          75% { transform: translateX(100px); opacity: 0.5; filter: blur(2px); }
          100% { transform: translateX(150px); opacity: 0; filter: blur(4px); }
        }

        @keyframes slideOutFromCenter {
          0% { transform: translateX(-150px); opacity: 0; filter: blur(4px); }
          5% { transform: translateX(-100px); opacity: 0.5; filter: blur(2px); }
          10% { transform: translateX(-50px); opacity: 1; filter: blur(0); }
          15% { transform: translateX(0); opacity: 1; filter: blur(0); }
          20% { transform: translateX(50px); opacity: 0.8; filter: blur(1px); }
          25% { transform: translateX(100px); opacity: 0.5; filter: blur(2px); }
          30% { transform: translateX(150px); opacity: 0; filter: blur(4px); }
          100% { transform: translateX(150px); opacity: 0; filter: blur(4px); }
        }
        
        @keyframes robotFlash {
          0% { background: linear-gradient(to bottom right, #0ea5e9, #0284c7); }
          30%, 70% { background: linear-gradient(to bottom right, #22c55e, #16a34a); }
          100% { background: linear-gradient(to bottom right, #0ea5e9, #0284c7); }
        }
      `}
      </style>
    </section>
  );
};

export default Hero;